# -*- coding: utf-8 -*-
from .errors import *
from .image import NaeginImage

import aiohttp

class Client:
    '''API Wrapper para Naeg.in

    - Descrição:
        Cria uma instância

    - Parâmetros:
        token : str
        (Token fornecido para usar a API)
    '''
    def __init__(self, token):
        if not isinstance(token, str):
            raise InvalidArgument('Tokens devem ser strings')

        self.url = 'https://api.naeg.in/{endpoint}?token=' + token

    async def get_all_tags(self):
        '''API Wrapper para Naeg.in

        - Descrição:
            Retorna todas as tags disponíveis em uma list
        '''
        async with aiohttp.ClientSession() as session:
            async with session.get(self.url.format(endpoint='tags')) as r:
                if r.status != 200:
                    raise InvalidResponse('Falha na requisição: Código inválido retornado')
            
                data = await r.json()
                if data['erro']:
                    raise InvalidArgument(data['mensagem'])
                
                return data['tags']

    async def get_random(self, tag, **kwargs):
        '''API Wrapper para Naeg.in

        - Descrição:
            Busca e retorna o link de uma imagem com a tag fornecida

        - Parâmetros:
            tag : str
            (Usada para buscar imagens)

            nsfw : bool (opcional)
            (Especifica se a API deve retornar apenas resultados NSFW ou não)

            gif : bool (opcional)
            (Define se a API deve retornar apenas imagens animadas ou não)
        '''
        url = self.url.format(endpoint='img') + f'&tag={tag}'
        for parameter, value in kwargs.items():
            url += f'&{parameter}={value}'

        async with aiohttp.ClientSession() as session:
            async with session.get(url) as r:
                if r.status != 200:
                    raise InvalidResponse('Falha na requisição: Código inválido retornado')
            
                data = await r.json()
                if data['erro']:
                    raise InvalidArgument(data['mensagem'])
            
                return NaeginImage(**data)


# -*- coding: utf-8 -*-
from setuptools import setup

rst = '''
Naegin
======

Naegin é uma API Wrapper para o site `naeg.in`_.

A API tem o objetivo de fornecer Imagens para desenvolvedores de bots
fazerem uso das mesmas em seus respectivos projetos.

Você precisa de um token para fazer uso desse serviço. Entre no
`Discord`_ do site para requisitar um.

Instalação
==========

Através do pip, você pode facilmente instalar a Wrapper, basta digitar
**``pip install naegin``** no terminal.

Certifique-se de estar usando o **Python 3.6+**.

Uso
===

.. code:: python

   import naegin

   #Cria uma instância para ser usada
   naegin = naegin.Client('token')

   #Pegar todas as tags disponíveis em uma list
   async def tags():
      tags = await naegin.get_all_tags()
      print(tags)

   #Pegar a URL de uma Imagem aleatória, com uma Tag especifica
   async def random(tag):
      image = await naegin.get_random(tag)
      print(image.url)

.. _naeg.in: https://naeg.in/
.. _Discord: https://discord.gg/kdb4Hvd3
'''

setup(
    name='naegin',
    author='Naegin',
    url='https://github.com/Naegin/naegin',
    version='1.0.3',
    packages=['naegin'],
    install_requires=['aiohttp'],
    description='API Wrapper em Python para Naegin',
    long_description=rst,
    license='MIT License',
    keywords=['naegin', 'api', 'wrapper', 'images', 'pt-br', 'brazilian', 'portuguese'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Natural Language :: Portuguese (Brazilian)',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet',
        'Topic :: Utilities',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)